# Python Package

## db_conn

To use this package is necessary create file on your home `~`

```bash
    "~/access_information.json"
        {
            "database_name": {
                "host": "database-db.host.net",
                "user": "user",
                "password": "1234",
                "database": "database_name",
                "port": 5432
            },
        }
```
